@@ -26,12 +26,12 @@ void get_hostent(char *host)
 struct in_addr saddr;
 int c;
 
-if (host==NULL) { fprintf(stderr,"No hostname given !\n"); exit(-1); }
+if (host==NULL) { fprintf(stderr,"No hostname given !\r\n"); exit(-1); }
 c=*host;
 if (isdigit(c)) 
 {
  saddr.s_addr = inet_addr(host); 
- hi = gethostbyaddr(&saddr,sizeof(struct in_addr),AF_INET);
+ hi = gethostbyaddr((char *)&saddr,sizeof(struct in_addr),AF_INET);
 }
 else hi = gethostbyname(host);
 }
@@ -53,21 +53,21 @@ struct sockaddr_in	address;
   perror("Could not get host information:");
   exit(-1);
  }
- fprintf(stderr,"Official host name: %s\n", hi->h_name );
+ fprintf(stderr,"Official host name: %s\r\n", hi->h_name );
  while ( (ptr = *(hi->h_aliases)) != NULL )
  {
-  fprintf(stderr,"Alias %s\n", ptr );
+  fprintf(stderr,"Alias %s\r\n", ptr );
   hi->h_aliases++;
  }
  if ( hi->h_addrtype != AF_INET )
  {
-  fprintf(stderr,"Unsupported address type.\n" );
+  fprintf(stderr,"Unsupported address type.\r\n" );
   exit(-1);
  }
  while ( (aptr = (struct in_addr *)*(hi->h_addr_list)++) != NULL )
  {
   saddr = *aptr;
-  fprintf(stderr,"Address: %s\n", inet_ntoa(*aptr) );
+  fprintf(stderr,"Address: %s\r\n", inet_ntoa(*aptr) );
  }
 
  /*
@@ -92,19 +92,22 @@ struct sockaddr_in	address;
   perror("Connect failed:");
   failure();
  }
- fprintf(stderr,"Connected to %s\n",hi->h_name);
+ fprintf(stderr,"Connected to %s\r\n",hi->h_name);
 }
 
 /*
  get a CR\NL terminated line from newsserver.
- sgetline doesn't really care for maxlen yet ;)
+ sgetline now checks for maxlen. this means lines > 1024 bytes
+ or > maxlen will be truncated automatically with all good/bad consequences.
 */
 int	sgetline(int fd, char *sbuf, int maxlen)
 {
 int	ret;
 char *ptr;
 static int count=0;
-static char tempbuf[1025];
+static char tempbuf[1030];
+
+ if (maxlen>1024 || maxlen<1) maxlen=1024;
 
  if (count>0)			/* some bytes left from previous sgetline */
  {
@@ -115,11 +118,12 @@ fputs(tempbuf,debugfp);
 fputc('\n',debugfp);
 #endif
   if (ptr!=NULL) goto returnline;
+  if (count>=maxlen) { ptr=&tempbuf[maxlen-1]; goto returnline; }
  }
 
  do
  {
-  ret=recv(fd, &tempbuf[count], 1024-count, 0);
+  ret=recv(fd, &tempbuf[count], maxlen-count, 0);
   if (ret<1) { perror("socket error: "); failure(); }
   count+=ret;
   tempbuf[count]='\0'; /* for strstr to work */
