@@ -1,25 +1,25 @@
 #include <stdio.h>
 
-#define RNEWS "/usr/local/lib/news/bin/input/rnews"
+#define RNEWS "/usr/lib/news/rnews"
 
 extern int errno;
 
 /* get news data from stdin and post it to the local server */
 
-main()
+void main(int argc,char**argv)
 {
-FILE *pfp;
+FILE *pfp=NULL;
 char line[1024];
-int count = 0;
-int len;
+int len,count=0,verbose=0;
+
+ if (argc>1) verbose=1;
 
- pfp = NULL;
  while ( gets(line) != NULL)
  {
   len=strlen(line);
   if ( line[0] == '.' && len == 1) /* end of article */
   {
-	fprintf(stderr,"end of article %d\n",count);
+    if (verbose) fprintf(stderr,"end of article %d\n",count);
     if ( pfp != NULL )
 	{
 	 pclose(pfp);
@@ -30,7 +30,7 @@ int len;
 
   if (pfp == NULL)
   {
-   fprintf(stderr,"posting article %d\n", ++count);
+   if (verbose) fprintf(stderr,"posting article %d\n", ++count);
    pfp = popen(RNEWS, "w");
    if ( pfp == NULL )
    {
@@ -40,4 +40,5 @@ int len;
   }
   fputs(line, pfp); putc('\n', pfp);
  } /* end while */
+ exit(0);
 }
