@@ -5,13 +5,12 @@
 #define ORGANIZATION "USU (United Suck Users)"
 #define DOMAIN "math.tu-berlin.de"
 
-main(int argc, char **argv)
+void main(int argc, char **argv)
 {
 char buf[1024];
 struct passwd *pw;
 int response,len;
 
-
 #ifdef DEBUG
 debugfp=fopen("rpost.debug","w");
 #endif
@@ -84,4 +83,6 @@ debugfp=fopen("rpost.debug","w");
 #ifdef DEBUG
 fclose(debugfp);
 #endif
+
+exit(0);
 }
