@@ -2,8 +2,11 @@
 #include "both.h"
 int articleCount=0;
 
+/* function prototypes */
+void get_message_index(void);
+void get_articles(long);
 
-get_message_index()
+void get_message_index()
 {
 int count,low,high,response,lastread;
 char *sp,buf[1025],group[512];
@@ -50,12 +53,12 @@ FILE *indexfp,*ifp,*tmpfp;
   sp = number(buf, &response);
   if (sp == NULL)
   {
-   fprintf(stderr,"Protocol error!\n");
+   fprintf(stderr,"Protocol error!\r\n");
    failure();
   }
   if ( response != 211 )
   {
-   fprintf(stderr,"GROUP <%s>, unexpected response %d\n", group, response );
+   fprintf(stderr,"GROUP <%s>, unexpected response %d\r\n", group, response );
    continue; /* next newsgroup */
   }
   sp = number( sp, &count );
@@ -64,11 +67,12 @@ FILE *indexfp,*ifp,*tmpfp;
   
   fprintf(tmpfp, "%s %d\n", group, high);
   
-  if ( lastread && lastread < high )
+  if ( lastread >= 0 && lastread < high ) 
   {
-   if ( lastread < low ) lastread = low;
+   if ( lastread < low ) lastread = low -1;
+   
    sprintf( buf, "xhdr Message-ID %d-\r\n", lastread+1 );
-   fprintf(stderr,"%s...articles %d-%d\n", group, lastread+1, high);
+   fprintf(stderr,"%s...articles %d-%d\r\n", group, lastread+1, high);
    sputline( sockfd, buf );
    sgetline( sockfd, buf, 1024 );
    number(buf, &response);
@@ -79,7 +83,9 @@ FILE *indexfp,*ifp,*tmpfp;
      sgetline( sockfd, buf, 1024 );
      if (buf[0] != '.' )
      {
-      for ( sp = buf; *sp != '<'; sp++ ) ;
+      for ( sp = buf; *sp != '<'; sp++ ) /* find begin of index */
+	   if (sp==&buf[1020]) continue; /* the NNTP server tried */
+	                                 /* to pull your leg */
       fprintf( indexfp, "%s\n", sp );
       articleCount++;
      }
@@ -87,7 +93,7 @@ FILE *indexfp,*ifp,*tmpfp;
    } /* end if response */
    else
    {
-    fprintf(stderr,"Unexpected response %d getting IDs\n", response );
+    fprintf(stderr,"Unexpected response %d getting IDs\r\n", response );
     failure();
    }
   } /* end if lastread */
@@ -124,10 +130,10 @@ FILE *logfp,*ifp;
 									sprintf(buf,"article "))
  {
   rewind(logfp);
-  fprintf(logfp,"%d\n%d\n",offset,articleCount);
+  fprintf(logfp,"%ld\n%d\n",offset,articleCount);
   fflush(logfp);
   offset=ftell(ifp);
-  fprintf(stderr,"%d\n", articleCount--);
+  fprintf(stderr,"%5d\r", articleCount--);
   len=strlen(buf);
   buf[len++]='\r';
   buf[len++]='\n';
@@ -143,7 +149,7 @@ fputs(buf,debugfp);
 
   if ( response != 220 )
   {
-   fprintf(stderr,"*** Warning: Unexpected response\n*** ");
+   fprintf(stderr,"*** Warning: Unexpected response\r\n*** ");
    fputs(buf,stderr);
    fputc('\n',stderr);
    continue;
@@ -163,7 +169,7 @@ fputs(buf,debugfp);
 }
 
 
-main(int argc, char **argv)
+void main(int argc, char **argv)
 {
 char buf[1024];
 FILE *fp;
@@ -180,42 +186,44 @@ debugfp=fopen("suck.debug","w");
  */
 
  sgetline(sockfd, buf, 1024);
- fprintf(stderr,"%s\n", buf );
+ fprintf(stderr,"%s\r\n", buf );
 
  sputline(sockfd,"mode reader\r\n");
  sgetline(sockfd,buf,1024); /* Again the announcement */
- fprintf(stderr,"%s\n",buf);
+ fprintf(stderr,"%s\r\n",buf);
 
  get_message_index();
 
  switch(articleCount)
  {
  case 0:
- 	fprintf(stderr,"No articles.\n");
+ 	fprintf(stderr,"No articles.\r\n");
 	goto end;
 	break;
  case -1:
 	fp = fopen("suck.restart","r");
-	fscanf(fp,"%d\n%d\n",&offset,&articleCount);
+	fscanf(fp,"%ld\n%d\n",&offset,&articleCount);
 	fclose(fp);
-	fprintf(stderr,"Initiating restart at article %d\n",articleCount);
+	fprintf(stderr,"Initiating restart at article %d\r\n",articleCount);
 	break;
  default:
 	unlink("suck.sorted");
-	fprintf(stderr,"Removing duplicates from list of %d articles.\n",
+	fprintf(stderr,"Removing duplicates from list of %d articles.\r\n",
 													articleCount);
 	system("sort suck.index | uniq > suck.sorted");
   }
 	
   get_articles(offset);
-  fprintf(stderr,"skipped %d duplicates\n",articleCount);
+  fprintf(stderr,"skipped %d duplicates\r\n",articleCount);
 
 end:
- fprintf(stderr,"Closing connection to %s\n",hi->h_name);
+ fprintf(stderr,"Closing connection to %s\r\n",hi->h_name);
  sputline( sockfd, "quit\r\n" );
  close(sockfd);
 #ifdef DEBUG
 fclose(debugfp);
 #endif
+
+exit(0);
 }
 
